
---
# DC Motor 23 click

> PRVIH_PAR_RECENICA_SA_PRODUCT_PAGE_DA_ISPRATE_CELINU

<p align="center">
  <img src="CLICK_IMAGE_LINK" height=300px>
</p>

[click Product page](CLICK_PRODUCT_PAGE_LINK)

---


#### Click library

- **Author**        : Nenad Filipovic
- **Date**          : Jan 2023.
- **Type**          : I2C type


# Software Support

We provide a library for the DC Motor 23 Click
as well as a demo application (example), developed using MikroElektronika
[compilers](https://www.mikroe.com/necto-studio).
The demo can run on all the main MikroElektronika [development boards](https://www.mikroe.com/development-boards).

Package can be downloaded/installed directly from *NECTO Studio Package Manager*(recommended way), downloaded from our [LibStock&trade;](https://libstock.mikroe.com) or found on [Mikroe github account](https://github.com/MikroElektronika/mikrosdk_click_v2/tree/master/clicks).

## Library Description

> This library contains API for DC Motor 23 Click driver.

#### Standard key functions :

- `dcmotor23_cfg_setup` Config Object Initialization function.
```c
void dcmotor23_cfg_setup ( dcmotor23_cfg_t *cfg );
```

- `dcmotor23_init` Initialization function.
```c
err_t dcmotor23_init ( dcmotor23_t *ctx, dcmotor23_cfg_t *cfg );
```

- `dcmotor23_default_cfg` Click Default Configuration function.
```c
err_t dcmotor23_default_cfg ( dcmotor23_t *ctx );
```

#### Example key functions :

- `dcmotor23_set_clockwise` DC Motor 23 set clockwise function.
```c
err_t dcmotor23_set_clockwise ( dcmotor23_t *ctx, uint8_t sel_motor );
```

- `dcmotor23_set_counter_clockwise` DC Motor 23 set counter clockwise function.
```c
err_t dcmotor23_set_counter_clockwise ( dcmotor23_t *ctx, uint8_t sel_motor );
```

- `dcmotor23_set_decay` DC Motor 23 set decay function.
```c
err_t dcmotor23_set_decay ( dcmotor23_t *ctx, uint8_t sel_motor );
```

## Example Description

> This example demonstrates the use of DC Motor 23 click board™. 
> by driving the motors in both direction every 3 seconds.

**The demo application is composed of two sections :**

### Application Init

> Initializes the driver and performs the click default configuration 
> which sets the output torque to 100%.

```c
void application_init ( void ) 
{
    log_cfg_t log_cfg;  /**< Logger config object. */
    dcmotor23_cfg_t dcmotor23_cfg;  /**< Click config object. */

    /** 
     * Logger initialization.
     * Default baud rate: 115200
     * Default log level: LOG_LEVEL_DEBUG
     * @note If USB_UART_RX and USB_UART_TX 
     * are defined as HAL_PIN_NC, you will 
     * need to define them manually for log to work. 
     * See @b LOG_MAP_USB_UART macro definition for detailed explanation.
     */
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, " Application Init " );

    // Click initialization.
    dcmotor23_cfg_setup( &dcmotor23_cfg );
    DCMOTOR23_MAP_MIKROBUS( dcmotor23_cfg, MIKROBUS_1 );
    if ( I2C_MASTER_ERROR == dcmotor23_init( &dcmotor23, &dcmotor23_cfg ) ) 
    {
        log_error( &logger, " Communication init." );
        for ( ; ; );
    }

    if ( DCMOTOR23_ERROR == dcmotor23_default_cfg ( &dcmotor23 ) )
    {
        log_error( &logger, " Default configuration." );
        for ( ; ; );
    }

    log_info( &logger, " Application Task " );
    log_printf ( &logger, "--------------------------\r\n" );
}

```

### Application Task

> This example demonstrates the use of the DC Motor 23  Click board™.
> Drives the motors in the clockwise direction,
> after that decay the motors with a 3 seconds delay
> then switches to the counter-clockwise direction, 
> and decay the motors with a 3 seconds delay.
> Results are being sent to the UART Terminal, where you can track their changes.

```c
void application_task ( void ) 
{    
    if ( DCMOTOR23_OK == dcmotor23_set_clockwise( &dcmotor23, DCMOTOR23_SEL_OUT_A ) )
    {
        log_printf ( &logger, " OUTA: Clockwise\r\n" );
    }
    if ( DCMOTOR23_OK == dcmotor23_set_clockwise( &dcmotor23, DCMOTOR23_SEL_OUT_B ) )
    {
        log_printf ( &logger, " OUTB: Clockwise\r\n\n" );
    }
    Delay_ms ( 3000 );

    if ( DCMOTOR23_OK == dcmotor23_set_decay( &dcmotor23, DCMOTOR23_SEL_OUT_A ) )
    {
        log_printf ( &logger, " OUTA: Decay\r\n" );
    }
    if ( DCMOTOR23_OK == dcmotor23_set_decay( &dcmotor23, DCMOTOR23_SEL_OUT_B ) )
    {
        log_printf ( &logger, " OUTB: Decay\r\n\n" );
    }
    Delay_ms ( 3000 );

    if ( DCMOTOR23_OK == dcmotor23_set_counter_clockwise( &dcmotor23, DCMOTOR23_SEL_OUT_A ) )
    {
        log_printf ( &logger, " OUTA: Counter-Clockwise\r\n" );
    }
    if ( DCMOTOR23_OK == dcmotor23_set_counter_clockwise( &dcmotor23, DCMOTOR23_SEL_OUT_B ) )
    {
        log_printf ( &logger, " OUTB: Counter-Clockwise\r\n\n" );
    }
    Delay_ms ( 3000 );

    if ( DCMOTOR23_OK == dcmotor23_set_decay( &dcmotor23, DCMOTOR23_SEL_OUT_A ) )
    {
        log_printf ( &logger, " OUTA: Decay\r\n" );
    }
    if ( DCMOTOR23_OK == dcmotor23_set_decay( &dcmotor23, DCMOTOR23_SEL_OUT_B ) )
    {
        log_printf ( &logger, " OUTB: Decay\r\n\n" );
    }
    log_printf ( &logger, "--------------------------\r\n" );
    Delay_ms ( 3000 );
}
```

The full application code, and ready to use projects can be installed directly from *NECTO Studio Package Manager*(recommended way), downloaded from our [LibStock&trade;](https://libstock.mikroe.com) or found on [Mikroe github account](https://github.com/MikroElektronika/mikrosdk_click_v2/tree/master/clicks).

**Other Mikroe Libraries used in the example:**

- MikroSDK.Board
- MikroSDK.Log
- Click.DCMotor23

**Additional notes and informations**

Depending on the development board you are using, you may need
[USB UART click](https://www.mikroe.com/usb-uart-click),
[USB UART 2 Click](https://www.mikroe.com/usb-uart-2-click) or
[RS232 Click](https://www.mikroe.com/rs232-click) to connect to your PC, for
development systems with no UART to USB interface available on the board. UART
terminal is available in all MikroElektronika
[compilers](https://shop.mikroe.com/compilers).

---
